@@ -8,7 +8,8 @@ import microcontroller
 import socketpool
 import wifi
 
-from adafruit_httpserver import HTTPServer, HTTPResponse
+from adafruit_httpserver.server import HTTPServer
+from adafruit_httpserver.response import HTTPResponse
 
 ssid = secrets["ssid"]
 print("Connecting to", ssid)
